# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.email_notification import EmailNotification
from bitmovin_api_sdk.models.encoding_error_email_notification import EncodingErrorEmailNotification
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError


class ErrorApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(ErrorApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, encoding_error_email_notification, **kwargs):
        # type: (EncodingErrorEmailNotification, dict) -> EncodingErrorEmailNotification
        """Add Encoding Error Email Notification (All Encodings)

        :param encoding_error_email_notification: Add a new email notification if an encoding received an error
        :type encoding_error_email_notification: EncodingErrorEmailNotification, required
        :return: Notification Details
        :rtype: EncodingErrorEmailNotification
        """

        return self.api_client.post(
            '/notifications/emails/encoding/encodings/error',
            encoding_error_email_notification,
            pagination_response=True,
            type=EncodingErrorEmailNotification,
            **kwargs
        )

    def create_by_encoding_id(self, encoding_id, email_notification, **kwargs):
        # type: (string_types, EmailNotification, dict) -> EmailNotification
        """Add Encoding Error Email Notification (Specific Encoding)

        :param encoding_id: Id of the encoding resource
        :type encoding_id: string_types, required
        :param email_notification: The email notifications object
        :type email_notification: EmailNotification, required
        :return: Notification Details
        :rtype: EmailNotification
        """

        return self.api_client.post(
            '/notifications/emails/encoding/encodings/{encoding_id}/error',
            email_notification,
            path_params={'encoding_id': encoding_id},
            type=EmailNotification,
            **kwargs
        )

    def update(self, notification_id, email_notification, **kwargs):
        # type: (string_types, EmailNotification, dict) -> EmailNotification
        """Replace Encoding Error Email Notification

        :param notification_id: Id of the email notification
        :type notification_id: string_types, required
        :param email_notification: The email notification with the updated values
        :type email_notification: EmailNotification, required
        :return: Notification Details
        :rtype: EmailNotification
        """

        return self.api_client.put(
            '/notifications/emails/encoding/encodings/error/{notification_id}',
            email_notification,
            path_params={'notification_id': notification_id},
            type=EmailNotification,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class CdnProvider(Enum):
    AKAMAI = "AKAMAI"
    AWS = "AWS"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.condition_operator import ConditionOperator
from bitmovin_api_sdk.models.default_manifest_condition import DefaultManifestCondition
import pprint
import six


class DefaultManifestAttributeCondition(DefaultManifestCondition):
    @poscheck_model
    def __init__(self,
                 attribute=None,
                 operator=None,
                 value=None):
        # type: (string_types, ConditionOperator, string_types) -> None
        super(DefaultManifestAttributeCondition, self).__init__()

        self._attribute = None
        self._operator = None
        self._value = None
        self.discriminator = None

        if attribute is not None:
            self.attribute = attribute
        if operator is not None:
            self.operator = operator
        if value is not None:
            self.value = value

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(DefaultManifestAttributeCondition, self), 'openapi_types'):
            types = getattr(super(DefaultManifestAttributeCondition, self), 'openapi_types')

        types.update({
            'attribute': 'string_types',
            'operator': 'ConditionOperator',
            'value': 'string_types'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(DefaultManifestAttributeCondition, self), 'attribute_map'):
            attributes = getattr(super(DefaultManifestAttributeCondition, self), 'attribute_map')

        attributes.update({
            'attribute': 'attribute',
            'operator': 'operator',
            'value': 'value'
        })
        return attributes

    @property
    def attribute(self):
        # type: () -> string_types
        """Gets the attribute of this DefaultManifestAttributeCondition.

        The attribute that should be used for the evaluation: - audio.codec - audio.language - audio.bitrate - subtitle.format - subtitle.language - video.height - video.width - video.codec - video.bitrate - drm.type - muxing.type (required)

        :return: The attribute of this DefaultManifestAttributeCondition.
        :rtype: string_types
        """
        return self._attribute

    @attribute.setter
    def attribute(self, attribute):
        # type: (string_types) -> None
        """Sets the attribute of this DefaultManifestAttributeCondition.

        The attribute that should be used for the evaluation: - audio.codec - audio.language - audio.bitrate - subtitle.format - subtitle.language - video.height - video.width - video.codec - video.bitrate - drm.type - muxing.type (required)

        :param attribute: The attribute of this DefaultManifestAttributeCondition.
        :type: string_types
        """

        if attribute is not None:
            if not isinstance(attribute, string_types):
                raise TypeError("Invalid type for `attribute`, type has to be `string_types`")

        self._attribute = attribute

    @property
    def operator(self):
        # type: () -> ConditionOperator
        """Gets the operator of this DefaultManifestAttributeCondition.

        The operator that should be used for the evaluation (required)

        :return: The operator of this DefaultManifestAttributeCondition.
        :rtype: ConditionOperator
        """
        return self._operator

    @operator.setter
    def operator(self, operator):
        # type: (ConditionOperator) -> None
        """Sets the operator of this DefaultManifestAttributeCondition.

        The operator that should be used for the evaluation (required)

        :param operator: The operator of this DefaultManifestAttributeCondition.
        :type: ConditionOperator
        """

        if operator is not None:
            if not isinstance(operator, ConditionOperator):
                raise TypeError("Invalid type for `operator`, type has to be `ConditionOperator`")

        self._operator = operator

    @property
    def value(self):
        # type: () -> string_types
        """Gets the value of this DefaultManifestAttributeCondition.

        The value that should be used for comparison. Valid values depend on the attribute: - audio.codec (Enum; e.g., AAC, MP3, OPUS) - audio.language (String) - audio.bitrate (Integer) - subtitle.format (Enum; e.g., WEBVTT) - subtitle.language (String) - video.height (Integer) - video.width (Integer) - video.codec (Enum; e.g., AV1, H264, VP9) - video.bitrate (Integer) - drm.type (Enum; NoDrm, Cenc, CencWidevine, CencPlayReady, CencMarlin, CencFairPlay, Aes128, ClearKey, PrimeTime, Widevine, PlayReady, Marlin, FairPlay) - muxing.type (Enum; e.g., FMP4, MP4) (required)

        :return: The value of this DefaultManifestAttributeCondition.
        :rtype: string_types
        """
        return self._value

    @value.setter
    def value(self, value):
        # type: (string_types) -> None
        """Sets the value of this DefaultManifestAttributeCondition.

        The value that should be used for comparison. Valid values depend on the attribute: - audio.codec (Enum; e.g., AAC, MP3, OPUS) - audio.language (String) - audio.bitrate (Integer) - subtitle.format (Enum; e.g., WEBVTT) - subtitle.language (String) - video.height (Integer) - video.width (Integer) - video.codec (Enum; e.g., AV1, H264, VP9) - video.bitrate (Integer) - drm.type (Enum; NoDrm, Cenc, CencWidevine, CencPlayReady, CencMarlin, CencFairPlay, Aes128, ClearKey, PrimeTime, Widevine, PlayReady, Marlin, FairPlay) - muxing.type (Enum; e.g., FMP4, MP4) (required)

        :param value: The value of this DefaultManifestAttributeCondition.
        :type: string_types
        """

        if value is not None:
            if not isinstance(value, string_types):
                raise TypeError("Invalid type for `value`, type has to be `string_types`")

        self._value = value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(DefaultManifestAttributeCondition, self), "to_dict"):
            result = super(DefaultManifestAttributeCondition, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DefaultManifestAttributeCondition):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.encodings.input_streams.trimming.timecode_track.timecode_track_api import TimecodeTrackApi
from bitmovin_api_sdk.encoding.encodings.input_streams.trimming.timecode_track.timecode_track_trimming_input_stream_list_query_params import TimecodeTrackTrimmingInputStreamListQueryParams



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.statistics_per_label import StatisticsPerLabel
from bitmovin_api_sdk.encoding.statistics.labels.daily.daily_api import DailyApi
from bitmovin_api_sdk.encoding.statistics.labels.statistics_per_label_list_query_params import StatisticsPerLabelListQueryParams
from bitmovin_api_sdk.encoding.statistics.labels.statistics_per_label_list_by_date_range_query_params import StatisticsPerLabelListByDateRangeQueryParams


class LabelsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(LabelsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.daily = DailyApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def list(self, query_params=None, **kwargs):
        # type: (StatisticsPerLabelListQueryParams, dict) -> StatisticsPerLabel
        """Get Statistics per Label

        :param query_params: Query parameters
        :type query_params: StatisticsPerLabelListQueryParams
        :return: List of encoding statistics for this label
        :rtype: StatisticsPerLabel
        """

        return self.api_client.get(
            '/encoding/statistics/labels',
            query_params=query_params,
            pagination_response=True,
            type=StatisticsPerLabel,
            **kwargs
        )

    def list_by_date_range(self, from_, to, query_params=None, **kwargs):
        # type: (date, date, StatisticsPerLabelListByDateRangeQueryParams, dict) -> StatisticsPerLabel
        """Get statistics per label within specific dates

        :param from_: Start date. Format: yyyy-MM-dd
        :type from_: date, required
        :param to: End date. Format: yyyy-MM-dd
        :type to: date, required
        :param query_params: Query parameters
        :type query_params: StatisticsPerLabelListByDateRangeQueryParams
        :return: List of encoding statistics for this label
        :rtype: StatisticsPerLabel
        """

        return self.api_client.get(
            '/encoding/statistics/labels/{from}/{to}',
            path_params={'from': from_, 'to': to},
            query_params=query_params,
            pagination_response=True,
            type=StatisticsPerLabel,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class ChannelsAttributeForAudio(Enum):
    ALWAYS = "ALWAYS"
    STANDARD_CONFORM = "STANDARD_CONFORM"
    LEGACY = "LEGACY"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.program_date_time_placement_mode import ProgramDateTimePlacementMode
import pprint
import six


class ProgramDateTimePlacement(object):
    @poscheck_model
    def __init__(self,
                 program_date_time_placement_mode=None,
                 interval=None):
        # type: (ProgramDateTimePlacementMode, int) -> None

        self._program_date_time_placement_mode = None
        self._interval = None
        self.discriminator = None

        if program_date_time_placement_mode is not None:
            self.program_date_time_placement_mode = program_date_time_placement_mode
        if interval is not None:
            self.interval = interval

    @property
    def openapi_types(self):
        types = {
            'program_date_time_placement_mode': 'ProgramDateTimePlacementMode',
            'interval': 'int'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'program_date_time_placement_mode': 'programDateTimePlacementMode',
            'interval': 'interval'
        }
        return attributes

    @property
    def program_date_time_placement_mode(self):
        # type: () -> ProgramDateTimePlacementMode
        """Gets the program_date_time_placement_mode of this ProgramDateTimePlacement.


        :return: The program_date_time_placement_mode of this ProgramDateTimePlacement.
        :rtype: ProgramDateTimePlacementMode
        """
        return self._program_date_time_placement_mode

    @program_date_time_placement_mode.setter
    def program_date_time_placement_mode(self, program_date_time_placement_mode):
        # type: (ProgramDateTimePlacementMode) -> None
        """Sets the program_date_time_placement_mode of this ProgramDateTimePlacement.


        :param program_date_time_placement_mode: The program_date_time_placement_mode of this ProgramDateTimePlacement.
        :type: ProgramDateTimePlacementMode
        """

        if program_date_time_placement_mode is not None:
            if not isinstance(program_date_time_placement_mode, ProgramDateTimePlacementMode):
                raise TypeError("Invalid type for `program_date_time_placement_mode`, type has to be `ProgramDateTimePlacementMode`")

        self._program_date_time_placement_mode = program_date_time_placement_mode

    @property
    def interval(self):
        # type: () -> int
        """Gets the interval of this ProgramDateTimePlacement.

        Interval for placing ProgramDateTime. Only required for SEGMENTS_INTERVAL or SECONDS_INTERVAL.

        :return: The interval of this ProgramDateTimePlacement.
        :rtype: int
        """
        return self._interval

    @interval.setter
    def interval(self, interval):
        # type: (int) -> None
        """Sets the interval of this ProgramDateTimePlacement.

        Interval for placing ProgramDateTime. Only required for SEGMENTS_INTERVAL or SECONDS_INTERVAL.

        :param interval: The interval of this ProgramDateTimePlacement.
        :type: int
        """

        if interval is not None:
            if not isinstance(interval, int):
                raise TypeError("Invalid type for `interval`, type has to be `int`")

        self._interval = interval

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProgramDateTimePlacement):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class MaxCtuSize(Enum):
    S16 = "16"
    S32 = "32"
    S64 = "64"



from bitmovin_api_sdk.encoding.encodings.input_streams.trimming.h264_picture_timing.h264_picture_timing_api import H264PictureTimingApi
from bitmovin_api_sdk.encoding.encodings.input_streams.trimming.h264_picture_timing.h264_picture_timing_trimming_input_stream_list_query_params import H264PictureTimingTrimmingInputStreamListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.live_standby_pool_event_log_type import LiveStandbyPoolEventLogType
import pprint
import six


class LiveStandbyPoolEventLog(object):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 standby_pool_id=None,
                 standby_pool_encoding_id=None,
                 created_at=None,
                 message=None,
                 details=None,
                 event_type=None):
        # type: (string_types, string_types, string_types, string_types, string_types, string_types, LiveStandbyPoolEventLogType) -> None

        self._id = None
        self._standby_pool_id = None
        self._standby_pool_encoding_id = None
        self._created_at = None
        self._message = None
        self._details = None
        self._event_type = None
        self.discriminator = None

        if id_ is not None:
            self.id = id_
        if standby_pool_id is not None:
            self.standby_pool_id = standby_pool_id
        if standby_pool_encoding_id is not None:
            self.standby_pool_encoding_id = standby_pool_encoding_id
        if created_at is not None:
            self.created_at = created_at
        if message is not None:
            self.message = message
        if details is not None:
            self.details = details
        if event_type is not None:
            self.event_type = event_type

    @property
    def openapi_types(self):
        types = {
            'id': 'string_types',
            'standby_pool_id': 'string_types',
            'standby_pool_encoding_id': 'string_types',
            'created_at': 'string_types',
            'message': 'string_types',
            'details': 'string_types',
            'event_type': 'LiveStandbyPoolEventLogType'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'id': 'id',
            'standby_pool_id': 'standbyPoolId',
            'standby_pool_encoding_id': 'standbyPoolEncodingId',
            'created_at': 'createdAt',
            'message': 'message',
            'details': 'details',
            'event_type': 'eventType'
        }
        return attributes

    @property
    def id(self):
        # type: () -> string_types
        """Gets the id of this LiveStandbyPoolEventLog.

        UUID of the entry

        :return: The id of this LiveStandbyPoolEventLog.
        :rtype: string_types
        """
        return self._id

    @id.setter
    def id(self, id_):
        # type: (string_types) -> None
        """Sets the id of this LiveStandbyPoolEventLog.

        UUID of the entry

        :param id_: The id of this LiveStandbyPoolEventLog.
        :type: string_types
        """

        if id_ is not None:
            if not isinstance(id_, string_types):
                raise TypeError("Invalid type for `id`, type has to be `string_types`")

        self._id = id_

    @property
    def standby_pool_id(self):
        # type: () -> string_types
        """Gets the standby_pool_id of this LiveStandbyPoolEventLog.

        Id of the standby_pool associated with the event log

        :return: The standby_pool_id of this LiveStandbyPoolEventLog.
        :rtype: string_types
        """
        return self._standby_pool_id

    @standby_pool_id.setter
    def standby_pool_id(self, standby_pool_id):
        # type: (string_types) -> None
        """Sets the standby_pool_id of this LiveStandbyPoolEventLog.

        Id of the standby_pool associated with the event log

        :param standby_pool_id: The standby_pool_id of this LiveStandbyPoolEventLog.
        :type: string_types
        """

        if standby_pool_id is not None:
            if not isinstance(standby_pool_id, string_types):
                raise TypeError("Invalid type for `standby_pool_id`, type has to be `string_types`")

        self._standby_pool_id = standby_pool_id

    @property
    def standby_pool_encoding_id(self):
        # type: () -> string_types
        """Gets the standby_pool_encoding_id of this LiveStandbyPoolEventLog.

        (Optional) Id of the standby pool encoding associated with the event

        :return: The standby_pool_encoding_id of this LiveStandbyPoolEventLog.
        :rtype: string_types
        """
        return self._standby_pool_encoding_id

    @standby_pool_encoding_id.setter
    def standby_pool_encoding_id(self, standby_pool_encoding_id):
        # type: (string_types) -> None
        """Sets the standby_pool_encoding_id of this LiveStandbyPoolEventLog.

        (Optional) Id of the standby pool encoding associated with the event

        :param standby_pool_encoding_id: The standby_pool_encoding_id of this LiveStandbyPoolEventLog.
        :type: string_types
        """

        if standby_pool_encoding_id is not None:
            if not isinstance(standby_pool_encoding_id, string_types):
                raise TypeError("Invalid type for `standby_pool_encoding_id`, type has to be `string_types`")

        self._standby_pool_encoding_id = standby_pool_encoding_id

    @property
    def created_at(self):
        # type: () -> string_types
        """Gets the created_at of this LiveStandbyPoolEventLog.

        Creation timestamp, returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ

        :return: The created_at of this LiveStandbyPoolEventLog.
        :rtype: string_types
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        # type: (string_types) -> None
        """Sets the created_at of this LiveStandbyPoolEventLog.

        Creation timestamp, returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ

        :param created_at: The created_at of this LiveStandbyPoolEventLog.
        :type: string_types
        """

        if created_at is not None:
            if not isinstance(created_at, string_types):
                raise TypeError("Invalid type for `created_at`, type has to be `string_types`")

        self._created_at = created_at

    @property
    def message(self):
        # type: () -> string_types
        """Gets the message of this LiveStandbyPoolEventLog.

        Short description of the event

        :return: The message of this LiveStandbyPoolEventLog.
        :rtype: string_types
        """
        return self._message

    @message.setter
    def message(self, message):
        # type: (string_types) -> None
        """Sets the message of this LiveStandbyPoolEventLog.

        Short description of the event

        :param message: The message of this LiveStandbyPoolEventLog.
        :type: string_types
        """

        if message is not None:
            if not isinstance(message, string_types):
                raise TypeError("Invalid type for `message`, type has to be `string_types`")

        self._message = message

    @property
    def details(self):
        # type: () -> string_types
        """Gets the details of this LiveStandbyPoolEventLog.

        Detailed description, payloads, hints on how to resolve errors, etc

        :return: The details of this LiveStandbyPoolEventLog.
        :rtype: string_types
        """
        return self._details

    @details.setter
    def details(self, details):
        # type: (string_types) -> None
        """Sets the details of this LiveStandbyPoolEventLog.

        Detailed description, payloads, hints on how to resolve errors, etc

        :param details: The details of this LiveStandbyPoolEventLog.
        :type: string_types
        """

        if details is not None:
            if not isinstance(details, string_types):
                raise TypeError("Invalid type for `details`, type has to be `string_types`")

        self._details = details

    @property
    def event_type(self):
        # type: () -> LiveStandbyPoolEventLogType
        """Gets the event_type of this LiveStandbyPoolEventLog.


        :return: The event_type of this LiveStandbyPoolEventLog.
        :rtype: LiveStandbyPoolEventLogType
        """
        return self._event_type

    @event_type.setter
    def event_type(self, event_type):
        # type: (LiveStandbyPoolEventLogType) -> None
        """Sets the event_type of this LiveStandbyPoolEventLog.


        :param event_type: The event_type of this LiveStandbyPoolEventLog.
        :type: LiveStandbyPoolEventLogType
        """

        if event_type is not None:
            if not isinstance(event_type, LiveStandbyPoolEventLogType):
                raise TypeError("Invalid type for `event_type`, type has to be `LiveStandbyPoolEventLogType`")

        self._event_type = event_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LiveStandbyPoolEventLog):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.ai_scene_analysis.analyses.by_encoding_id.by_encoding_id_api import ByEncodingIdApi
from bitmovin_api_sdk.ai_scene_analysis.analyses.by_encoding_id.details.details_api import DetailsApi



from bitmovin_api_sdk.streams.config.domain_restriction.domain_restriction_api import DomainRestrictionApi
from bitmovin_api_sdk.streams.config.domain_restriction.streams_domain_restriction_response_list_query_params import StreamsDomainRestrictionResponseListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.billable_encoding_minutes_details import BillableEncodingMinutesDetails
from bitmovin_api_sdk.models.codec_config_type import CodecConfigType
from bitmovin_api_sdk.models.encoding_mode import EncodingMode
from bitmovin_api_sdk.models.nex_guard_ab_watermarking_feature import NexGuardABWatermarkingFeature
from bitmovin_api_sdk.models.pixel_format_bit_depth import PixelFormatBitDepth
from bitmovin_api_sdk.models.psnr_per_stream_mode import PsnrPerStreamMode
from bitmovin_api_sdk.models.statistics_per_title_stream import StatisticsPerTitleStream
import pprint
import six


class BillableEncodingMinutes(object):
    @poscheck_model
    def __init__(self,
                 encoding_mode=None,
                 codec=None,
                 per_title_result_stream=None,
                 psnr_mode=None,
                 preset=None,
                 live=None,
                 enhanced_deinterlace=None,
                 nex_guard_ab_watermarking_type=None,
                 pixel_format_bit_depth=None,
                 billable_minutes=None):
        # type: (EncodingMode, CodecConfigType, StatisticsPerTitleStream, PsnrPerStreamMode, string_types, bool, bool, NexGuardABWatermarkingFeature, PixelFormatBitDepth, BillableEncodingMinutesDetails) -> None

        self._encoding_mode = None
        self._codec = None
        self._per_title_result_stream = None
        self._psnr_mode = None
        self._preset = None
        self._live = None
        self._enhanced_deinterlace = None
        self._nex_guard_ab_watermarking_type = None
        self._pixel_format_bit_depth = None
        self._billable_minutes = None
        self.discriminator = None

        if encoding_mode is not None:
            self.encoding_mode = encoding_mode
        if codec is not None:
            self.codec = codec
        if per_title_result_stream is not None:
            self.per_title_result_stream = per_title_result_stream
        if psnr_mode is not None:
            self.psnr_mode = psnr_mode
        if preset is not None:
            self.preset = preset
        if live is not None:
            self.live = live
        if enhanced_deinterlace is not None:
            self.enhanced_deinterlace = enhanced_deinterlace
        if nex_guard_ab_watermarking_type is not None:
            self.nex_guard_ab_watermarking_type = nex_guard_ab_watermarking_type
        if pixel_format_bit_depth is not None:
            self.pixel_format_bit_depth = pixel_format_bit_depth
        if billable_minutes is not None:
            self.billable_minutes = billable_minutes

    @property
    def openapi_types(self):
        types = {
            'encoding_mode': 'EncodingMode',
            'codec': 'CodecConfigType',
            'per_title_result_stream': 'StatisticsPerTitleStream',
            'psnr_mode': 'PsnrPerStreamMode',
            'preset': 'string_types',
            'live': 'bool',
            'enhanced_deinterlace': 'bool',
            'nex_guard_ab_watermarking_type': 'NexGuardABWatermarkingFeature',
            'pixel_format_bit_depth': 'PixelFormatBitDepth',
            'billable_minutes': 'BillableEncodingMinutesDetails'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'encoding_mode': 'encodingMode',
            'codec': 'codec',
            'per_title_result_stream': 'perTitleResultStream',
            'psnr_mode': 'psnrMode',
            'preset': 'preset',
            'live': 'live',
            'enhanced_deinterlace': 'enhancedDeinterlace',
            'nex_guard_ab_watermarking_type': 'nexGuardABWatermarkingType',
            'pixel_format_bit_depth': 'pixelFormatBitDepth',
            'billable_minutes': 'billableMinutes'
        }
        return attributes

    @property
    def encoding_mode(self):
        # type: () -> EncodingMode
        """Gets the encoding_mode of this BillableEncodingMinutes.


        :return: The encoding_mode of this BillableEncodingMinutes.
        :rtype: EncodingMode
        """
        return self._encoding_mode

    @encoding_mode.setter
    def encoding_mode(self, encoding_mode):
        # type: (EncodingMode) -> None
        """Sets the encoding_mode of this BillableEncodingMinutes.


        :param encoding_mode: The encoding_mode of this BillableEncodingMinutes.
        :type: EncodingMode
        """

        if encoding_mode is not None:
            if not isinstance(encoding_mode, EncodingMode):
                raise TypeError("Invalid type for `encoding_mode`, type has to be `EncodingMode`")

        self._encoding_mode = encoding_mode

    @property
    def codec(self):
        # type: () -> CodecConfigType
        """Gets the codec of this BillableEncodingMinutes.


        :return: The codec of this BillableEncodingMinutes.
        :rtype: CodecConfigType
        """
        return self._codec

    @codec.setter
    def codec(self, codec):
        # type: (CodecConfigType) -> None
        """Sets the codec of this BillableEncodingMinutes.


        :param codec: The codec of this BillableEncodingMinutes.
        :type: CodecConfigType
        """

        if codec is not None:
            if not isinstance(codec, CodecConfigType):
                raise TypeError("Invalid type for `codec`, type has to be `CodecConfigType`")

        self._codec = codec

    @property
    def per_title_result_stream(self):
        # type: () -> StatisticsPerTitleStream
        """Gets the per_title_result_stream of this BillableEncodingMinutes.


        :return: The per_title_result_stream of this BillableEncodingMinutes.
        :rtype: StatisticsPerTitleStream
        """
        return self._per_title_result_stream

    @per_title_result_stream.setter
    def per_title_result_stream(self, per_title_result_stream):
        # type: (StatisticsPerTitleStream) -> None
        """Sets the per_title_result_stream of this BillableEncodingMinutes.


        :param per_title_result_stream: The per_title_result_stream of this BillableEncodingMinutes.
        :type: StatisticsPerTitleStream
        """

        if per_title_result_stream is not None:
            if not isinstance(per_title_result_stream, StatisticsPerTitleStream):
                raise TypeError("Invalid type for `per_title_result_stream`, type has to be `StatisticsPerTitleStream`")

        self._per_title_result_stream = per_title_result_stream

    @property
    def psnr_mode(self):
        # type: () -> PsnrPerStreamMode
        """Gets the psnr_mode of this BillableEncodingMinutes.


        :return: The psnr_mode of this BillableEncodingMinutes.
        :rtype: PsnrPerStreamMode
        """
        return self._psnr_mode

    @psnr_mode.setter
    def psnr_mode(self, psnr_mode):
        # type: (PsnrPerStreamMode) -> None
        """Sets the psnr_mode of this BillableEncodingMinutes.


        :param psnr_mode: The psnr_mode of this BillableEncodingMinutes.
        :type: PsnrPerStreamMode
        """

        if psnr_mode is not None:
            if not isinstance(psnr_mode, PsnrPerStreamMode):
                raise TypeError("Invalid type for `psnr_mode`, type has to be `PsnrPerStreamMode`")

        self._psnr_mode = psnr_mode

    @property
    def preset(self):
        # type: () -> string_types
        """Gets the preset of this BillableEncodingMinutes.

        Name of the preset configuration used for the codec configuration or \"CUSTOM\" if any preset values were overridden

        :return: The preset of this BillableEncodingMinutes.
        :rtype: string_types
        """
        return self._preset

    @preset.setter
    def preset(self, preset):
        # type: (string_types) -> None
        """Sets the preset of this BillableEncodingMinutes.

        Name of the preset configuration used for the codec configuration or \"CUSTOM\" if any preset values were overridden

        :param preset: The preset of this BillableEncodingMinutes.
        :type: string_types
        """

        if preset is not None:
            if not isinstance(preset, string_types):
                raise TypeError("Invalid type for `preset`, type has to be `string_types`")

        self._preset = preset

    @property
    def live(self):
        # type: () -> bool
        """Gets the live of this BillableEncodingMinutes.

        Indicates if the stream was part of a live encoding.

        :return: The live of this BillableEncodingMinutes.
        :rtype: bool
        """
        return self._live

    @live.setter
    def live(self, live):
        # type: (bool) -> None
        """Sets the live of this BillableEncodingMinutes.

        Indicates if the stream was part of a live encoding.

        :param live: The live of this BillableEncodingMinutes.
        :type: bool
        """

        if live is not None:
            if not isinstance(live, bool):
                raise TypeError("Invalid type for `live`, type has to be `bool`")

        self._live = live

    @property
    def enhanced_deinterlace(self):
        # type: () -> bool
        """Gets the enhanced_deinterlace of this BillableEncodingMinutes.

        Indicates if an enhanced interlace filter was used.

        :return: The enhanced_deinterlace of this BillableEncodingMinutes.
        :rtype: bool
        """
        return self._enhanced_deinterlace

    @enhanced_deinterlace.setter
    def enhanced_deinterlace(self, enhanced_deinterlace):
        # type: (bool) -> None
        """Sets the enhanced_deinterlace of this BillableEncodingMinutes.

        Indicates if an enhanced interlace filter was used.

        :param enhanced_deinterlace: The enhanced_deinterlace of this BillableEncodingMinutes.
        :type: bool
        """

        if enhanced_deinterlace is not None:
            if not isinstance(enhanced_deinterlace, bool):
                raise TypeError("Invalid type for `enhanced_deinterlace`, type has to be `bool`")

        self._enhanced_deinterlace = enhanced_deinterlace

    @property
    def nex_guard_ab_watermarking_type(self):
        # type: () -> NexGuardABWatermarkingFeature
        """Gets the nex_guard_ab_watermarking_type of this BillableEncodingMinutes.


        :return: The nex_guard_ab_watermarking_type of this BillableEncodingMinutes.
        :rtype: NexGuardABWatermarkingFeature
        """
        return self._nex_guard_ab_watermarking_type

    @nex_guard_ab_watermarking_type.setter
    def nex_guard_ab_watermarking_type(self, nex_guard_ab_watermarking_type):
        # type: (NexGuardABWatermarkingFeature) -> None
        """Sets the nex_guard_ab_watermarking_type of this BillableEncodingMinutes.


        :param nex_guard_ab_watermarking_type: The nex_guard_ab_watermarking_type of this BillableEncodingMinutes.
        :type: NexGuardABWatermarkingFeature
        """

        if nex_guard_ab_watermarking_type is not None:
            if not isinstance(nex_guard_ab_watermarking_type, NexGuardABWatermarkingFeature):
                raise TypeError("Invalid type for `nex_guard_ab_watermarking_type`, type has to be `NexGuardABWatermarkingFeature`")

        self._nex_guard_ab_watermarking_type = nex_guard_ab_watermarking_type

    @property
    def pixel_format_bit_depth(self):
        # type: () -> PixelFormatBitDepth
        """Gets the pixel_format_bit_depth of this BillableEncodingMinutes.


        :return: The pixel_format_bit_depth of this BillableEncodingMinutes.
        :rtype: PixelFormatBitDepth
        """
        return self._pixel_format_bit_depth

    @pixel_format_bit_depth.setter
    def pixel_format_bit_depth(self, pixel_format_bit_depth):
        # type: (PixelFormatBitDepth) -> None
        """Sets the pixel_format_bit_depth of this BillableEncodingMinutes.


        :param pixel_format_bit_depth: The pixel_format_bit_depth of this BillableEncodingMinutes.
        :type: PixelFormatBitDepth
        """

        if pixel_format_bit_depth is not None:
            if not isinstance(pixel_format_bit_depth, PixelFormatBitDepth):
                raise TypeError("Invalid type for `pixel_format_bit_depth`, type has to be `PixelFormatBitDepth`")

        self._pixel_format_bit_depth = pixel_format_bit_depth

    @property
    def billable_minutes(self):
        # type: () -> BillableEncodingMinutesDetails
        """Gets the billable_minutes of this BillableEncodingMinutes.


        :return: The billable_minutes of this BillableEncodingMinutes.
        :rtype: BillableEncodingMinutesDetails
        """
        return self._billable_minutes

    @billable_minutes.setter
    def billable_minutes(self, billable_minutes):
        # type: (BillableEncodingMinutesDetails) -> None
        """Sets the billable_minutes of this BillableEncodingMinutes.


        :param billable_minutes: The billable_minutes of this BillableEncodingMinutes.
        :type: BillableEncodingMinutesDetails
        """

        if billable_minutes is not None:
            if not isinstance(billable_minutes, BillableEncodingMinutesDetails):
                raise TypeError("Invalid type for `billable_minutes`, type has to be `BillableEncodingMinutesDetails`")

        self._billable_minutes = billable_minutes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BillableEncodingMinutes):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.cache_control_settings_dash import CacheControlSettingsDash
from bitmovin_api_sdk.models.cache_control_settings_hls import CacheControlSettingsHls
from bitmovin_api_sdk.models.cache_control_settings_segments import CacheControlSettingsSegments
import pprint
import six


class CacheControlSettings(object):
    @poscheck_model
    def __init__(self,
                 hls=None,
                 dash=None,
                 segments=None):
        # type: (CacheControlSettingsHls, CacheControlSettingsDash, CacheControlSettingsSegments) -> None

        self._hls = None
        self._dash = None
        self._segments = None
        self.discriminator = None

        if hls is not None:
            self.hls = hls
        if dash is not None:
            self.dash = dash
        if segments is not None:
            self.segments = segments

    @property
    def openapi_types(self):
        types = {
            'hls': 'CacheControlSettingsHls',
            'dash': 'CacheControlSettingsDash',
            'segments': 'CacheControlSettingsSegments'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'hls': 'hls',
            'dash': 'dash',
            'segments': 'segments'
        }
        return attributes

    @property
    def hls(self):
        # type: () -> CacheControlSettingsHls
        """Gets the hls of this CacheControlSettings.

        Cache control settings for HLS manifest.

        :return: The hls of this CacheControlSettings.
        :rtype: CacheControlSettingsHls
        """
        return self._hls

    @hls.setter
    def hls(self, hls):
        # type: (CacheControlSettingsHls) -> None
        """Sets the hls of this CacheControlSettings.

        Cache control settings for HLS manifest.

        :param hls: The hls of this CacheControlSettings.
        :type: CacheControlSettingsHls
        """

        if hls is not None:
            if not isinstance(hls, CacheControlSettingsHls):
                raise TypeError("Invalid type for `hls`, type has to be `CacheControlSettingsHls`")

        self._hls = hls

    @property
    def dash(self):
        # type: () -> CacheControlSettingsDash
        """Gets the dash of this CacheControlSettings.

        Cache control settings for DASH manifest.

        :return: The dash of this CacheControlSettings.
        :rtype: CacheControlSettingsDash
        """
        return self._dash

    @dash.setter
    def dash(self, dash):
        # type: (CacheControlSettingsDash) -> None
        """Sets the dash of this CacheControlSettings.

        Cache control settings for DASH manifest.

        :param dash: The dash of this CacheControlSettings.
        :type: CacheControlSettingsDash
        """

        if dash is not None:
            if not isinstance(dash, CacheControlSettingsDash):
                raise TypeError("Invalid type for `dash`, type has to be `CacheControlSettingsDash`")

        self._dash = dash

    @property
    def segments(self):
        # type: () -> CacheControlSettingsSegments
        """Gets the segments of this CacheControlSettings.

        Cache control settings for segments.

        :return: The segments of this CacheControlSettings.
        :rtype: CacheControlSettingsSegments
        """
        return self._segments

    @segments.setter
    def segments(self, segments):
        # type: (CacheControlSettingsSegments) -> None
        """Sets the segments of this CacheControlSettings.

        Cache control settings for segments.

        :param segments: The segments of this CacheControlSettings.
        :type: CacheControlSettingsSegments
        """

        if segments is not None:
            if not isinstance(segments, CacheControlSettingsSegments):
                raise TypeError("Invalid type for `segments`, type has to be `CacheControlSettingsSegments`")

        self._segments = segments

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CacheControlSettings):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.cloud_region import CloudRegion
from bitmovin_api_sdk.models.static_ip_status import StaticIpStatus
import pprint
import six


class StaticIp(BitmovinResponse):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 ip_address=None,
                 infrastructure_id=None,
                 status=None,
                 region=None):
        # type: (string_types, string_types, string_types, StaticIpStatus, CloudRegion) -> None
        super(StaticIp, self).__init__(id_=id_)

        self._ip_address = None
        self._infrastructure_id = None
        self._status = None
        self._region = None
        self.discriminator = None

        if ip_address is not None:
            self.ip_address = ip_address
        if infrastructure_id is not None:
            self.infrastructure_id = infrastructure_id
        if status is not None:
            self.status = status
        if region is not None:
            self.region = region

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(StaticIp, self), 'openapi_types'):
            types = getattr(super(StaticIp, self), 'openapi_types')

        types.update({
            'ip_address': 'string_types',
            'infrastructure_id': 'string_types',
            'status': 'StaticIpStatus',
            'region': 'CloudRegion'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(StaticIp, self), 'attribute_map'):
            attributes = getattr(super(StaticIp, self), 'attribute_map')

        attributes.update({
            'ip_address': 'ipAddress',
            'infrastructure_id': 'infrastructureId',
            'status': 'status',
            'region': 'region'
        })
        return attributes

    @property
    def ip_address(self):
        # type: () -> string_types
        """Gets the ip_address of this StaticIp.

        The IPv4 address of the static ip

        :return: The ip_address of this StaticIp.
        :rtype: string_types
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        # type: (string_types) -> None
        """Sets the ip_address of this StaticIp.

        The IPv4 address of the static ip

        :param ip_address: The ip_address of this StaticIp.
        :type: string_types
        """

        if ip_address is not None:
            if not isinstance(ip_address, string_types):
                raise TypeError("Invalid type for `ip_address`, type has to be `string_types`")

        self._ip_address = ip_address

    @property
    def infrastructure_id(self):
        # type: () -> string_types
        """Gets the infrastructure_id of this StaticIp.

        Required if the static IP should be created for an AWS infrastructure account. If this is left blank the static Ip will be created for the managed cloud.

        :return: The infrastructure_id of this StaticIp.
        :rtype: string_types
        """
        return self._infrastructure_id

    @infrastructure_id.setter
    def infrastructure_id(self, infrastructure_id):
        # type: (string_types) -> None
        """Sets the infrastructure_id of this StaticIp.

        Required if the static IP should be created for an AWS infrastructure account. If this is left blank the static Ip will be created for the managed cloud.

        :param infrastructure_id: The infrastructure_id of this StaticIp.
        :type: string_types
        """

        if infrastructure_id is not None:
            if not isinstance(infrastructure_id, string_types):
                raise TypeError("Invalid type for `infrastructure_id`, type has to be `string_types`")

        self._infrastructure_id = infrastructure_id

    @property
    def status(self):
        # type: () -> StaticIpStatus
        """Gets the status of this StaticIp.

        Status of the Static Ip

        :return: The status of this StaticIp.
        :rtype: StaticIpStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        # type: (StaticIpStatus) -> None
        """Sets the status of this StaticIp.

        Status of the Static Ip

        :param status: The status of this StaticIp.
        :type: StaticIpStatus
        """

        if status is not None:
            if not isinstance(status, StaticIpStatus):
                raise TypeError("Invalid type for `status`, type has to be `StaticIpStatus`")

        self._status = status

    @property
    def region(self):
        # type: () -> CloudRegion
        """Gets the region of this StaticIp.

        The region of the static Ip (required)

        :return: The region of this StaticIp.
        :rtype: CloudRegion
        """
        return self._region

    @region.setter
    def region(self, region):
        # type: (CloudRegion) -> None
        """Sets the region of this StaticIp.

        The region of the static Ip (required)

        :param region: The region of this StaticIp.
        :type: CloudRegion
        """

        if region is not None:
            if not isinstance(region, CloudRegion):
                raise TypeError("Invalid type for `region`, type has to be `CloudRegion`")

        self._region = region

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(StaticIp, self), "to_dict"):
            result = super(StaticIp, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StaticIp):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class SourceChannelType(Enum):
    CHANNEL_NUMBER = "CHANNEL_NUMBER"
    FRONT_LEFT = "FRONT_LEFT"
    FRONT_RIGHT = "FRONT_RIGHT"
    CENTER = "CENTER"
    LOW_FREQUENCY = "LOW_FREQUENCY"
    BACK_LEFT = "BACK_LEFT"
    BACK_RIGHT = "BACK_RIGHT"
    SURROUND_LEFT = "SURROUND_LEFT"
    SURROUND_RIGHT = "SURROUND_RIGHT"



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.live_standby_pool_details import LiveStandbyPoolDetails
from bitmovin_api_sdk.models.live_standby_pool_request import LiveStandbyPoolRequest
from bitmovin_api_sdk.models.live_standby_pool_response import LiveStandbyPoolResponse
from bitmovin_api_sdk.models.live_standby_pool_update import LiveStandbyPoolUpdate
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.live.standby_pools.actions.actions_api import ActionsApi
from bitmovin_api_sdk.encoding.live.standby_pools.encodings.encodings_api import EncodingsApi
from bitmovin_api_sdk.encoding.live.standby_pools.logs.logs_api import LogsApi


class StandbyPoolsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(StandbyPoolsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.actions = ActionsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.encodings = EncodingsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.logs = LogsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, live_standby_pool_request, **kwargs):
        # type: (LiveStandbyPoolRequest, dict) -> LiveStandbyPoolDetails
        """Create new standby pool

        :param live_standby_pool_request: The pool to be created
        :type live_standby_pool_request: LiveStandbyPoolRequest, required
        :return:
        :rtype: LiveStandbyPoolDetails
        """

        return self.api_client.post(
            '/encoding/live/standby-pools',
            live_standby_pool_request,
            type=LiveStandbyPoolDetails,
            **kwargs
        )

    def delete(self, pool_id, **kwargs):
        # type: (string_types, dict) -> BitmovinResponse
        """Delete standby pool by id

        :param pool_id: Id of the standby pool
        :type pool_id: string_types, required
        :return: Id of the standby pool that was deleted
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/live/standby-pools/{pool_id}',
            path_params={'pool_id': pool_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, pool_id, **kwargs):
        # type: (string_types, dict) -> LiveStandbyPoolDetails
        """Get details of a standby pool by id

        :param pool_id: Id of the standby pool
        :type pool_id: string_types, required
        :return:
        :rtype: LiveStandbyPoolDetails
        """

        return self.api_client.get(
            '/encoding/live/standby-pools/{pool_id}',
            path_params={'pool_id': pool_id},
            type=LiveStandbyPoolDetails,
            **kwargs
        )

    def list(self, **kwargs):
        # type: (dict) -> LiveStandbyPoolResponse
        """List Standby pools

        :return: Standby pools list response
        :rtype: LiveStandbyPoolResponse
        """

        return self.api_client.get(
            '/encoding/live/standby-pools',
            pagination_response=True,
            type=LiveStandbyPoolResponse,
            **kwargs
        )

    def patch(self, pool_id, live_standby_pool_update, **kwargs):
        # type: (string_types, LiveStandbyPoolUpdate, dict) -> LiveStandbyPoolDetails
        """Partially update standby pool by id

        :param pool_id: Id of the standby pool
        :type pool_id: string_types, required
        :param live_standby_pool_update: The updated standby pool object.
        :type live_standby_pool_update: LiveStandbyPoolUpdate, required
        :return:
        :rtype: LiveStandbyPoolDetails
        """

        return self.api_client.patch(
            '/encoding/live/standby-pools/{pool_id}',
            live_standby_pool_update,
            path_params={'pool_id': pool_id},
            type=LiveStandbyPoolDetails,
            **kwargs
        )



from bitmovin_api_sdk.encoding.encodings.input_streams.input_streams_api import InputStreamsApi
from bitmovin_api_sdk.encoding.encodings.input_streams.type.type_api import TypeApi
from bitmovin_api_sdk.encoding.encodings.input_streams.audio_mix.audio_mix_api import AudioMixApi
from bitmovin_api_sdk.encoding.encodings.input_streams.ingest.ingest_api import IngestApi
from bitmovin_api_sdk.encoding.encodings.input_streams.sidecar.sidecar_api import SidecarApi
from bitmovin_api_sdk.encoding.encodings.input_streams.concatenation.concatenation_api import ConcatenationApi
from bitmovin_api_sdk.encoding.encodings.input_streams.file.file_api import FileApi
from bitmovin_api_sdk.encoding.encodings.input_streams.trimming.trimming_api import TrimmingApi
from bitmovin_api_sdk.encoding.encodings.input_streams.subtitles.subtitles_api import SubtitlesApi
from bitmovin_api_sdk.encoding.encodings.input_streams.captions.captions_api import CaptionsApi
from bitmovin_api_sdk.encoding.encodings.input_streams.dolby_atmos.dolby_atmos_api import DolbyAtmosApi
from bitmovin_api_sdk.encoding.encodings.input_streams.dolby_vision.dolby_vision_api import DolbyVisionApi
from bitmovin_api_sdk.encoding.encodings.input_streams.input_stream_list_query_params import InputStreamListQueryParams



from bitmovin_api_sdk.notifications.webhooks.encoding.encodings.live_encoding_heartbeat.live_encoding_heartbeat_api import LiveEncodingHeartbeatApi
from bitmovin_api_sdk.notifications.webhooks.encoding.encodings.live_encoding_heartbeat.live_encoding_heartbeat_webhook_list_query_params import LiveEncodingHeartbeatWebhookListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class TuInterDepth(Enum):
    D1 = "1"
    D2 = "2"
    D3 = "3"
    D4 = "4"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class Atmosphere(object):
    @poscheck_model
    def __init__(self,
                 mood=None,
                 lighting=None,
                 weather=None):
        # type: (string_types, string_types, string_types) -> None

        self._mood = None
        self._lighting = None
        self._weather = None
        self.discriminator = None

        if mood is not None:
            self.mood = mood
        if lighting is not None:
            self.lighting = lighting
        if weather is not None:
            self.weather = weather

    @property
    def openapi_types(self):
        types = {
            'mood': 'string_types',
            'lighting': 'string_types',
            'weather': 'string_types'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'mood': 'mood',
            'lighting': 'lighting',
            'weather': 'weather'
        }
        return attributes

    @property
    def mood(self):
        # type: () -> string_types
        """Gets the mood of this Atmosphere.


        :return: The mood of this Atmosphere.
        :rtype: string_types
        """
        return self._mood

    @mood.setter
    def mood(self, mood):
        # type: (string_types) -> None
        """Sets the mood of this Atmosphere.


        :param mood: The mood of this Atmosphere.
        :type: string_types
        """

        if mood is not None:
            if not isinstance(mood, string_types):
                raise TypeError("Invalid type for `mood`, type has to be `string_types`")

        self._mood = mood

    @property
    def lighting(self):
        # type: () -> string_types
        """Gets the lighting of this Atmosphere.


        :return: The lighting of this Atmosphere.
        :rtype: string_types
        """
        return self._lighting

    @lighting.setter
    def lighting(self, lighting):
        # type: (string_types) -> None
        """Sets the lighting of this Atmosphere.


        :param lighting: The lighting of this Atmosphere.
        :type: string_types
        """

        if lighting is not None:
            if not isinstance(lighting, string_types):
                raise TypeError("Invalid type for `lighting`, type has to be `string_types`")

        self._lighting = lighting

    @property
    def weather(self):
        # type: () -> string_types
        """Gets the weather of this Atmosphere.


        :return: The weather of this Atmosphere.
        :rtype: string_types
        """
        return self._weather

    @weather.setter
    def weather(self, weather):
        # type: (string_types) -> None
        """Sets the weather of this Atmosphere.


        :param weather: The weather of this Atmosphere.
        :type: string_types
        """

        if weather is not None:
            if not isinstance(weather, string_types):
                raise TypeError("Invalid type for `weather`, type has to be `string_types`")

        self._weather = weather

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Atmosphere):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.encodings.input_streams.captions.cea608.cea608_api import Cea608Api
from bitmovin_api_sdk.encoding.encodings.input_streams.captions.cea608.cea608_caption_input_stream_list_query_params import Cea608CaptionInputStreamListQueryParams



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.analytics_count_query_request import AnalyticsCountQueryRequest
from bitmovin_api_sdk.models.analytics_query_request import AnalyticsQueryRequest
from bitmovin_api_sdk.models.analytics_response import AnalyticsResponse
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError


class CountApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(CountApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, analytics_count_query_request, **kwargs):
        # type: (AnalyticsCountQueryRequest, dict) -> AnalyticsResponse
        """Count

        :param analytics_count_query_request: Analytics Query Object
        :type analytics_count_query_request: AnalyticsCountQueryRequest, required
        :return: Service specific result
        :rtype: AnalyticsResponse
        """

        return self.api_client.post(
            '/analytics/queries/count',
            analytics_count_query_request,
            type=AnalyticsResponse,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitmovin_resource import BitmovinResource
from bitmovin_api_sdk.models.google_cloud_region import GoogleCloudRegion
import pprint
import six


class GceAccountRegionSettings(BitmovinResource):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 network=None,
                 subnet_id=None,
                 region=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, string_types, string_types, GoogleCloudRegion) -> None
        super(GceAccountRegionSettings, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._network = None
        self._subnet_id = None
        self._region = None
        self.discriminator = None

        if network is not None:
            self.network = network
        if subnet_id is not None:
            self.subnet_id = subnet_id
        if region is not None:
            self.region = region

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(GceAccountRegionSettings, self), 'openapi_types'):
            types = getattr(super(GceAccountRegionSettings, self), 'openapi_types')

        types.update({
            'network': 'string_types',
            'subnet_id': 'string_types',
            'region': 'GoogleCloudRegion'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(GceAccountRegionSettings, self), 'attribute_map'):
            attributes = getattr(super(GceAccountRegionSettings, self), 'attribute_map')

        attributes.update({
            'network': 'network',
            'subnet_id': 'subnetId',
            'region': 'region'
        })
        return attributes

    @property
    def network(self):
        # type: () -> string_types
        """Gets the network of this GceAccountRegionSettings.

        Id of the network for encoding instances (required)

        :return: The network of this GceAccountRegionSettings.
        :rtype: string_types
        """
        return self._network

    @network.setter
    def network(self, network):
        # type: (string_types) -> None
        """Sets the network of this GceAccountRegionSettings.

        Id of the network for encoding instances (required)

        :param network: The network of this GceAccountRegionSettings.
        :type: string_types
        """

        if network is not None:
            if not isinstance(network, string_types):
                raise TypeError("Invalid type for `network`, type has to be `string_types`")

        self._network = network

    @property
    def subnet_id(self):
        # type: () -> string_types
        """Gets the subnet_id of this GceAccountRegionSettings.

        Id of the subnet for encoding instances (required)

        :return: The subnet_id of this GceAccountRegionSettings.
        :rtype: string_types
        """
        return self._subnet_id

    @subnet_id.setter
    def subnet_id(self, subnet_id):
        # type: (string_types) -> None
        """Sets the subnet_id of this GceAccountRegionSettings.

        Id of the subnet for encoding instances (required)

        :param subnet_id: The subnet_id of this GceAccountRegionSettings.
        :type: string_types
        """

        if subnet_id is not None:
            if not isinstance(subnet_id, string_types):
                raise TypeError("Invalid type for `subnet_id`, type has to be `string_types`")

        self._subnet_id = subnet_id

    @property
    def region(self):
        # type: () -> GoogleCloudRegion
        """Gets the region of this GceAccountRegionSettings.


        :return: The region of this GceAccountRegionSettings.
        :rtype: GoogleCloudRegion
        """
        return self._region

    @region.setter
    def region(self, region):
        # type: (GoogleCloudRegion) -> None
        """Sets the region of this GceAccountRegionSettings.


        :param region: The region of this GceAccountRegionSettings.
        :type: GoogleCloudRegion
        """

        if region is not None:
            if not isinstance(region, GoogleCloudRegion):
                raise TypeError("Invalid type for `region`, type has to be `GoogleCloudRegion`")

        self._region = region

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(GceAccountRegionSettings, self), "to_dict"):
            result = super(GceAccountRegionSettings, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GceAccountRegionSettings):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.imsc.imsc_api import ImscApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.imsc.dash_imsc_representation_list_query_params import DashImscRepresentationListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class LiveStandbyPoolStatus(Enum):
    HEALTHY = "HEALTHY"
    ERROR = "ERROR"



from bitmovin_api_sdk.encoding.statistics.encodings.live_statistics.srt.srt_api import SrtApi
from bitmovin_api_sdk.encoding.statistics.encodings.live_statistics.srt.srt_statistics_list_query_params import SrtStatisticsListQueryParams
from bitmovin_api_sdk.encoding.statistics.encodings.live_statistics.srt.srt_statistics_list_by_srt_input_id_query_params import SrtStatisticsListBySrtInputIdQueryParams



from abc import abstractmethod


class BitmovinApiLoggerBase(object):
    @abstractmethod
    def log(self, message, data=None):
        # type: (str, object) -> None
        pass

    @abstractmethod
    def error(self, message, data=None):
        # type: (str, object) -> None
        pass



from bitmovin_api_sdk.encoding.outputs.generic_s3.generic_s3_api import GenericS3Api
from bitmovin_api_sdk.encoding.outputs.generic_s3.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.outputs.generic_s3.generic_s3_output_list_query_params import GenericS3OutputListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class PrewarmedEncoderDiskSize(Enum):
    GB_500 = "500"
    GB_1000 = "1000"
    GB_2000 = "2000"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.cea608_channel_type import Cea608ChannelType
from bitmovin_api_sdk.models.input_stream import InputStream
import pprint
import six


class Cea608CaptionInputStream(InputStream):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 input_id=None,
                 input_path=None,
                 channel=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, string_types, string_types, Cea608ChannelType) -> None
        super(Cea608CaptionInputStream, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._input_id = None
        self._input_path = None
        self._channel = None
        self.discriminator = None

        if input_id is not None:
            self.input_id = input_id
        if input_path is not None:
            self.input_path = input_path
        if channel is not None:
            self.channel = channel

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(Cea608CaptionInputStream, self), 'openapi_types'):
            types = getattr(super(Cea608CaptionInputStream, self), 'openapi_types')

        types.update({
            'input_id': 'string_types',
            'input_path': 'string_types',
            'channel': 'Cea608ChannelType'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(Cea608CaptionInputStream, self), 'attribute_map'):
            attributes = getattr(super(Cea608CaptionInputStream, self), 'attribute_map')

        attributes.update({
            'input_id': 'inputId',
            'input_path': 'inputPath',
            'channel': 'channel'
        })
        return attributes

    @property
    def input_id(self):
        # type: () -> string_types
        """Gets the input_id of this Cea608CaptionInputStream.

        Id of the Input (required)

        :return: The input_id of this Cea608CaptionInputStream.
        :rtype: string_types
        """
        return self._input_id

    @input_id.setter
    def input_id(self, input_id):
        # type: (string_types) -> None
        """Sets the input_id of this Cea608CaptionInputStream.

        Id of the Input (required)

        :param input_id: The input_id of this Cea608CaptionInputStream.
        :type: string_types
        """

        if input_id is not None:
            if not isinstance(input_id, string_types):
                raise TypeError("Invalid type for `input_id`, type has to be `string_types`")

        self._input_id = input_id

    @property
    def input_path(self):
        # type: () -> string_types
        """Gets the input_path of this Cea608CaptionInputStream.

        Path to media file (required)

        :return: The input_path of this Cea608CaptionInputStream.
        :rtype: string_types
        """
        return self._input_path

    @input_path.setter
    def input_path(self, input_path):
        # type: (string_types) -> None
        """Sets the input_path of this Cea608CaptionInputStream.

        Path to media file (required)

        :param input_path: The input_path of this Cea608CaptionInputStream.
        :type: string_types
        """

        if input_path is not None:
            if not isinstance(input_path, string_types):
                raise TypeError("Invalid type for `input_path`, type has to be `string_types`")

        self._input_path = input_path

    @property
    def channel(self):
        # type: () -> Cea608ChannelType
        """Gets the channel of this Cea608CaptionInputStream.

        The channel number of the subtitle on the respective stream position (required)

        :return: The channel of this Cea608CaptionInputStream.
        :rtype: Cea608ChannelType
        """
        return self._channel

    @channel.setter
    def channel(self, channel):
        # type: (Cea608ChannelType) -> None
        """Sets the channel of this Cea608CaptionInputStream.

        The channel number of the subtitle on the respective stream position (required)

        :param channel: The channel of this Cea608CaptionInputStream.
        :type: Cea608ChannelType
        """

        if channel is not None:
            if not isinstance(channel, Cea608ChannelType):
                raise TypeError("Invalid type for `channel`, type has to be `Cea608ChannelType`")

        self._channel = channel

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(Cea608CaptionInputStream, self), "to_dict"):
            result = super(Cea608CaptionInputStream, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Cea608CaptionInputStream):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.channels_attribute_for_audio import ChannelsAttributeForAudio
from bitmovin_api_sdk.models.hls_manifest import HlsManifest
from bitmovin_api_sdk.models.hls_manifest_default_version import HlsManifestDefaultVersion
from bitmovin_api_sdk.models.hls_target_duration_rounding_mode import HlsTargetDurationRoundingMode
from bitmovin_api_sdk.models.hls_version import HlsVersion
from bitmovin_api_sdk.models.manifest_type import ManifestType
from bitmovin_api_sdk.models.status import Status
import pprint
import six


class HlsManifestDefault(HlsManifest):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 type_=None,
                 outputs=None,
                 status=None,
                 manifest_name=None,
                 hls_media_playlist_version=None,
                 hls_master_playlist_version=None,
                 channels_attribute_for_audio=None,
                 target_duration_rounding_mode=None,
                 encoding_id=None,
                 version=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, ManifestType, list[EncodingOutput], Status, string_types, HlsVersion, HlsVersion, ChannelsAttributeForAudio, HlsTargetDurationRoundingMode, string_types, HlsManifestDefaultVersion) -> None
        super(HlsManifestDefault, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data, type_=type_, outputs=outputs, status=status, manifest_name=manifest_name, hls_media_playlist_version=hls_media_playlist_version, hls_master_playlist_version=hls_master_playlist_version, channels_attribute_for_audio=channels_attribute_for_audio, target_duration_rounding_mode=target_duration_rounding_mode)

        self._encoding_id = None
        self._version = None
        self.discriminator = None

        if encoding_id is not None:
            self.encoding_id = encoding_id
        if version is not None:
            self.version = version

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(HlsManifestDefault, self), 'openapi_types'):
            types = getattr(super(HlsManifestDefault, self), 'openapi_types')

        types.update({
            'encoding_id': 'string_types',
            'version': 'HlsManifestDefaultVersion'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(HlsManifestDefault, self), 'attribute_map'):
            attributes = getattr(super(HlsManifestDefault, self), 'attribute_map')

        attributes.update({
            'encoding_id': 'encodingId',
            'version': 'version'
        })
        return attributes

    @property
    def encoding_id(self):
        # type: () -> string_types
        """Gets the encoding_id of this HlsManifestDefault.

        The id of the encoding to create a default manifest for (required)

        :return: The encoding_id of this HlsManifestDefault.
        :rtype: string_types
        """
        return self._encoding_id

    @encoding_id.setter
    def encoding_id(self, encoding_id):
        # type: (string_types) -> None
        """Sets the encoding_id of this HlsManifestDefault.

        The id of the encoding to create a default manifest for (required)

        :param encoding_id: The encoding_id of this HlsManifestDefault.
        :type: string_types
        """

        if encoding_id is not None:
            if not isinstance(encoding_id, string_types):
                raise TypeError("Invalid type for `encoding_id`, type has to be `string_types`")

        self._encoding_id = encoding_id

    @property
    def version(self):
        # type: () -> HlsManifestDefaultVersion
        """Gets the version of this HlsManifestDefault.

        Currently not in use

        :return: The version of this HlsManifestDefault.
        :rtype: HlsManifestDefaultVersion
        """
        return self._version

    @version.setter
    def version(self, version):
        # type: (HlsManifestDefaultVersion) -> None
        """Sets the version of this HlsManifestDefault.

        Currently not in use

        :param version: The version of this HlsManifestDefault.
        :type: HlsManifestDefaultVersion
        """

        if version is not None:
            if not isinstance(version, HlsManifestDefaultVersion):
                raise TypeError("Invalid type for `version`, type has to be `HlsManifestDefaultVersion`")

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(HlsManifestDefault, self), "to_dict"):
            result = super(HlsManifestDefault, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HlsManifestDefault):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class AzureCloudRegion(Enum):
    ASIA_EAST = "ASIA_EAST"
    ASIA_SOUTHEAST = "ASIA_SOUTHEAST"
    AUSTRALIA_EAST = "AUSTRALIA_EAST"
    AUSTRALIA_SOUTHEAST = "AUSTRALIA_SOUTHEAST"
    BRAZIL_SOUTH = "BRAZIL_SOUTH"
    CANADA_CENTRAL = "CANADA_CENTRAL"
    EUROPE_NORTH = "EUROPE_NORTH"
    EUROPE_WEST = "EUROPE_WEST"
    FRANCE_CENTRAL = "FRANCE_CENTRAL"
    GERMANY_WESTCENTRAL = "GERMANY_WESTCENTRAL"
    INDIA_CENTRAL = "INDIA_CENTRAL"
    INDIA_SOUTH = "INDIA_SOUTH"
    JAPAN_EAST = "JAPAN_EAST"
    JAPAN_WEST = "JAPAN_WEST"
    KOREA_CENTRAL = "KOREA_CENTRAL"
    UAE_NORTH = "UAE_NORTH"
    US_CENTRAL = "US_CENTRAL"
    US_EAST = "US_EAST"
    US_EAST2 = "US_EAST2"
    US_WEST = "US_WEST"
    US_WEST2 = "US_WEST2"
    US_SOUTH_CENTRAL = "US_SOUTH_CENTRAL"
    US_NORTH_CENTRAL = "US_NORTH_CENTRAL"
    UK_SOUTH = "UK_SOUTH"



from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.chunked_text.chunked_text_api import ChunkedTextApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.chunked_text.dash_chunked_text_representation_list_query_params import DashChunkedTextRepresentationListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class HlsManifestAdMarkerType(Enum):
    EXT_X_CUE_OUT_IN = "EXT_X_CUE_OUT_IN"
    EXT_OATCLS_SCTE35 = "EXT_OATCLS_SCTE35"
    EXT_X_SPLICEPOINT_SCTE35 = "EXT_X_SPLICEPOINT_SCTE35"
    EXT_X_DATERANGE = "EXT_X_DATERANGE"
    EXT_X_SCTE35 = "EXT_X_SCTE35"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class MediaConfigBitrate(Enum):
    MCB_160000 = "160000"
    MCB_192000 = "192000"
    MCB_224000 = "224000"
    MCB_256000 = "256000"
    MCB_288000 = "288000"
    MCB_320000 = "320000"
    MCB_384000 = "384000"
    MCB_448000 = "448000"



from bitmovin_api_sdk.encoding.encodings.muxings.progressive_ts.id3.plain_text.plain_text_api import PlainTextApi
from bitmovin_api_sdk.encoding.encodings.muxings.progressive_ts.id3.plain_text.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.encodings.muxings.progressive_ts.id3.plain_text.plaintext_id3_tag_list_query_params import PlaintextId3TagListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class AudioMixChannelLayout(Enum):
    NONE = "NONE"
    CL_MONO = "MONO"
    CL_STEREO = "STEREO"
    CL_SURROUND = "SURROUND"
    CL_QUAD = "QUAD"
    CL_OCTAGONAL = "OCTAGONAL"
    CL_HEXAGONAL = "HEXAGONAL"
    CL_STEREO_DOWNMIX = "STEREO_DOWNMIX"
    CL_2_1 = "2.1"
    CL_2_2 = "2.2"
    CL_3_1 = "3.1"
    CL_4_0 = "4.0"
    CL_4_1 = "4.1"
    CL_5_0 = "5.0"
    CL_5_1 = "5.1"
    CL_5_0_BACK = "5.0_BACK"
    CL_5_1_BACK = "5.1_BACK"
    CL_6_0 = "6.0"
    CL_6_0_FRONT = "6.0_FRONT"
    CL_6_1 = "6.1"
    CL_6_1_BACK = "6.1_BACK"
    CL_6_1_FRONT = "6.1_FRONT"
    CL_7_0 = "7.0"
    CL_7_0_FRONT = "7.0_FRONT"
    CL_7_1 = "7.1"
    CL_7_1_WIDE = "7.1_WIDE"
    CL_7_1_WIDE_BACK = "7.1_WIDE_BACK"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class IABTaxonomy(object):
    @poscheck_model
    def __init__(self,
                 version=None,
                 content_taxonomies=None,
                 ad_opportunity_taxonomies=None,
                 sensitive_topic_taxonomies=None):
        # type: (string_types, list[string_types], list[string_types], list[string_types]) -> None

        self._version = None
        self._content_taxonomies = list()
        self._ad_opportunity_taxonomies = list()
        self._sensitive_topic_taxonomies = list()
        self.discriminator = None

        if version is not None:
            self.version = version
        if content_taxonomies is not None:
            self.content_taxonomies = content_taxonomies
        if ad_opportunity_taxonomies is not None:
            self.ad_opportunity_taxonomies = ad_opportunity_taxonomies
        if sensitive_topic_taxonomies is not None:
            self.sensitive_topic_taxonomies = sensitive_topic_taxonomies

    @property
    def openapi_types(self):
        types = {
            'version': 'string_types',
            'content_taxonomies': 'list[string_types]',
            'ad_opportunity_taxonomies': 'list[string_types]',
            'sensitive_topic_taxonomies': 'list[string_types]'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'version': 'version',
            'content_taxonomies': 'contentTaxonomies',
            'ad_opportunity_taxonomies': 'adOpportunityTaxonomies',
            'sensitive_topic_taxonomies': 'sensitiveTopicTaxonomies'
        }
        return attributes

    @property
    def version(self):
        # type: () -> string_types
        """Gets the version of this IABTaxonomy.


        :return: The version of this IABTaxonomy.
        :rtype: string_types
        """
        return self._version

    @version.setter
    def version(self, version):
        # type: (string_types) -> None
        """Sets the version of this IABTaxonomy.


        :param version: The version of this IABTaxonomy.
        :type: string_types
        """

        if version is not None:
            if not isinstance(version, string_types):
                raise TypeError("Invalid type for `version`, type has to be `string_types`")

        self._version = version

    @property
    def content_taxonomies(self):
        # type: () -> list[string_types]
        """Gets the content_taxonomies of this IABTaxonomy.


        :return: The content_taxonomies of this IABTaxonomy.
        :rtype: list[string_types]
        """
        return self._content_taxonomies

    @content_taxonomies.setter
    def content_taxonomies(self, content_taxonomies):
        # type: (list) -> None
        """Sets the content_taxonomies of this IABTaxonomy.


        :param content_taxonomies: The content_taxonomies of this IABTaxonomy.
        :type: list[string_types]
        """

        if content_taxonomies is not None:
            if not isinstance(content_taxonomies, list):
                raise TypeError("Invalid type for `content_taxonomies`, type has to be `list[string_types]`")

        self._content_taxonomies = content_taxonomies

    @property
    def ad_opportunity_taxonomies(self):
        # type: () -> list[string_types]
        """Gets the ad_opportunity_taxonomies of this IABTaxonomy.


        :return: The ad_opportunity_taxonomies of this IABTaxonomy.
        :rtype: list[string_types]
        """
        return self._ad_opportunity_taxonomies

    @ad_opportunity_taxonomies.setter
    def ad_opportunity_taxonomies(self, ad_opportunity_taxonomies):
        # type: (list) -> None
        """Sets the ad_opportunity_taxonomies of this IABTaxonomy.


        :param ad_opportunity_taxonomies: The ad_opportunity_taxonomies of this IABTaxonomy.
        :type: list[string_types]
        """

        if ad_opportunity_taxonomies is not None:
            if not isinstance(ad_opportunity_taxonomies, list):
                raise TypeError("Invalid type for `ad_opportunity_taxonomies`, type has to be `list[string_types]`")

        self._ad_opportunity_taxonomies = ad_opportunity_taxonomies

    @property
    def sensitive_topic_taxonomies(self):
        # type: () -> list[string_types]
        """Gets the sensitive_topic_taxonomies of this IABTaxonomy.


        :return: The sensitive_topic_taxonomies of this IABTaxonomy.
        :rtype: list[string_types]
        """
        return self._sensitive_topic_taxonomies

    @sensitive_topic_taxonomies.setter
    def sensitive_topic_taxonomies(self, sensitive_topic_taxonomies):
        # type: (list) -> None
        """Sets the sensitive_topic_taxonomies of this IABTaxonomy.


        :param sensitive_topic_taxonomies: The sensitive_topic_taxonomies of this IABTaxonomy.
        :type: list[string_types]
        """

        if sensitive_topic_taxonomies is not None:
            if not isinstance(sensitive_topic_taxonomies, list):
                raise TypeError("Invalid type for `sensitive_topic_taxonomies`, type has to be `list[string_types]`")

        self._sensitive_topic_taxonomies = sensitive_topic_taxonomies

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IABTaxonomy):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.convert_scc_caption import ConvertSccCaption
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.encodings.captions.scc.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.encodings.captions.scc.convert_scc_caption_list_query_params import ConvertSccCaptionListQueryParams


class SccApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(SccApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.customdata = CustomdataApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, encoding_id, convert_scc_caption, **kwargs):
        # type: (string_types, ConvertSccCaption, dict) -> ConvertSccCaption
        """Convert SCC captions

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param convert_scc_caption: The SCC captions to be created
        :type convert_scc_caption: ConvertSccCaption, required
        :return: Caption resource
        :rtype: ConvertSccCaption
        """

        return self.api_client.post(
            '/encoding/encodings/{encoding_id}/captions/scc',
            convert_scc_caption,
            path_params={'encoding_id': encoding_id},
            type=ConvertSccCaption,
            **kwargs
        )

    def delete(self, encoding_id, captions_id, **kwargs):
        # type: (string_types, string_types, dict) -> BitmovinResponse
        """Delete Convert SCC captions

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param captions_id: Id of the caption.
        :type captions_id: string_types, required
        :return: Id of the caption
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/encodings/{encoding_id}/captions/scc/{captions_id}',
            path_params={'encoding_id': encoding_id, 'captions_id': captions_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, encoding_id, captions_id, **kwargs):
        # type: (string_types, string_types, dict) -> ConvertSccCaption
        """Convert SCC captions Details

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param captions_id: Id of the caption.
        :type captions_id: string_types, required
        :return: Caption
        :rtype: ConvertSccCaption
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/captions/scc/{captions_id}',
            path_params={'encoding_id': encoding_id, 'captions_id': captions_id},
            type=ConvertSccCaption,
            **kwargs
        )

    def list(self, encoding_id, query_params=None, **kwargs):
        # type: (string_types, ConvertSccCaptionListQueryParams, dict) -> ConvertSccCaption
        """List Convert SCC captions

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param query_params: Query parameters
        :type query_params: ConvertSccCaptionListQueryParams
        :return: List of caption configurations
        :rtype: ConvertSccCaption
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/captions/scc',
            path_params={'encoding_id': encoding_id},
            query_params=query_params,
            pagination_response=True,
            type=ConvertSccCaption,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class HlsManifestAdMarkerSettings(object):
    @poscheck_model
    def __init__(self,
                 enabled_marker_types=None):
        # type: (list[HlsManifestAdMarkerType]) -> None

        self._enabled_marker_types = list()
        self.discriminator = None

        if enabled_marker_types is not None:
            self.enabled_marker_types = enabled_marker_types

    @property
    def openapi_types(self):
        types = {
            'enabled_marker_types': 'list[HlsManifestAdMarkerType]'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'enabled_marker_types': 'enabledMarkerTypes'
        }
        return attributes

    @property
    def enabled_marker_types(self):
        # type: () -> list[HlsManifestAdMarkerType]
        """Gets the enabled_marker_types of this HlsManifestAdMarkerSettings.

        Ad marker types that will be inserted. More than one type is possible.  - EXT_X_CUE_OUT_IN: Ad markers will be inserted using `#EXT-X-CUE-OUT` and `#EXT-X-CUE-IN` tags - EXT_OATCLS_SCTE35: Ad markers will be inserted using `#EXT-OATCLS-SCTE35` tags. They contain the base64 encoded raw bytes of the original SCTE-35 trigger. - EXT_X_SPLICEPOINT_SCTE35: Ad markers will be inserted using `#EXT-X-SPLICEPOINT-SCTE35` tags. They contain the base64 encoded raw bytes of the original SCTE-35 trigger. - EXT_X_DATERANGE: Ad markers will be inserted using `#EXT-X-DATERANGE` tags. They contain the ID, start timestamp and hex encoded raw bytes of the original SCTE-35 trigger. - EXT_X_SCTE35: Ad markers will be inserted using `#EXT-X-SCTE35` tags. They contain the base64 encoded raw bytes of the original SCTE-35 trigger. 

        :return: The enabled_marker_types of this HlsManifestAdMarkerSettings.
        :rtype: list[HlsManifestAdMarkerType]
        """
        return self._enabled_marker_types

    @enabled_marker_types.setter
    def enabled_marker_types(self, enabled_marker_types):
        # type: (list) -> None
        """Sets the enabled_marker_types of this HlsManifestAdMarkerSettings.

        Ad marker types that will be inserted. More than one type is possible.  - EXT_X_CUE_OUT_IN: Ad markers will be inserted using `#EXT-X-CUE-OUT` and `#EXT-X-CUE-IN` tags - EXT_OATCLS_SCTE35: Ad markers will be inserted using `#EXT-OATCLS-SCTE35` tags. They contain the base64 encoded raw bytes of the original SCTE-35 trigger. - EXT_X_SPLICEPOINT_SCTE35: Ad markers will be inserted using `#EXT-X-SPLICEPOINT-SCTE35` tags. They contain the base64 encoded raw bytes of the original SCTE-35 trigger. - EXT_X_DATERANGE: Ad markers will be inserted using `#EXT-X-DATERANGE` tags. They contain the ID, start timestamp and hex encoded raw bytes of the original SCTE-35 trigger. - EXT_X_SCTE35: Ad markers will be inserted using `#EXT-X-SCTE35` tags. They contain the base64 encoded raw bytes of the original SCTE-35 trigger. 

        :param enabled_marker_types: The enabled_marker_types of this HlsManifestAdMarkerSettings.
        :type: list[HlsManifestAdMarkerType]
        """

        if enabled_marker_types is not None:
            if not isinstance(enabled_marker_types, list):
                raise TypeError("Invalid type for `enabled_marker_types`, type has to be `list[HlsManifestAdMarkerType]`")

        self._enabled_marker_types = enabled_marker_types

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HlsManifestAdMarkerSettings):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.configurations.subtitles.subtitles_api import SubtitlesApi
from bitmovin_api_sdk.encoding.configurations.subtitles.dvb_subtitle.dvb_subtitle_api import DvbSubtitleApi
from bitmovin_api_sdk.encoding.configurations.subtitles.webvtt.webvtt_api import WebvttApi
from bitmovin_api_sdk.encoding.configurations.subtitles.imsc.imsc_api import ImscApi



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class VariantStreamDroppingMode(Enum):
    STREAM = "STREAM"
    AUDIO = "AUDIO"



from bitmovin_api_sdk.encoding.filters.unsharp.unsharp_api import UnsharpApi
from bitmovin_api_sdk.encoding.filters.unsharp.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.filters.unsharp.unsharp_filter_list_query_params import UnsharpFilterListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class ProgressiveTsMuxingInformationByteRanges(object):
    @poscheck_model
    def __init__(self,
                 segment_number=None,
                 start_bytes=None,
                 end_bytes=None,
                 duration=None):
        # type: (int, int, int, float) -> None

        self._segment_number = None
        self._start_bytes = None
        self._end_bytes = None
        self._duration = None
        self.discriminator = None

        if segment_number is not None:
            self.segment_number = segment_number
        if start_bytes is not None:
            self.start_bytes = start_bytes
        if end_bytes is not None:
            self.end_bytes = end_bytes
        if duration is not None:
            self.duration = duration

    @property
    def openapi_types(self):
        types = {
            'segment_number': 'int',
            'start_bytes': 'int',
            'end_bytes': 'int',
            'duration': 'float'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'segment_number': 'segmentNumber',
            'start_bytes': 'startBytes',
            'end_bytes': 'endBytes',
            'duration': 'duration'
        }
        return attributes

    @property
    def segment_number(self):
        # type: () -> int
        """Gets the segment_number of this ProgressiveTsMuxingInformationByteRanges.

        Number of the segment (starting at 0) (required)

        :return: The segment_number of this ProgressiveTsMuxingInformationByteRanges.
        :rtype: int
        """
        return self._segment_number

    @segment_number.setter
    def segment_number(self, segment_number):
        # type: (int) -> None
        """Sets the segment_number of this ProgressiveTsMuxingInformationByteRanges.

        Number of the segment (starting at 0) (required)

        :param segment_number: The segment_number of this ProgressiveTsMuxingInformationByteRanges.
        :type: int
        """

        if segment_number is not None:
            if not isinstance(segment_number, int):
                raise TypeError("Invalid type for `segment_number`, type has to be `int`")

        self._segment_number = segment_number

    @property
    def start_bytes(self):
        # type: () -> int
        """Gets the start_bytes of this ProgressiveTsMuxingInformationByteRanges.

        The position of the first byte of the segment

        :return: The start_bytes of this ProgressiveTsMuxingInformationByteRanges.
        :rtype: int
        """
        return self._start_bytes

    @start_bytes.setter
    def start_bytes(self, start_bytes):
        # type: (int) -> None
        """Sets the start_bytes of this ProgressiveTsMuxingInformationByteRanges.

        The position of the first byte of the segment

        :param start_bytes: The start_bytes of this ProgressiveTsMuxingInformationByteRanges.
        :type: int
        """

        if start_bytes is not None:
            if not isinstance(start_bytes, int):
                raise TypeError("Invalid type for `start_bytes`, type has to be `int`")

        self._start_bytes = start_bytes

    @property
    def end_bytes(self):
        # type: () -> int
        """Gets the end_bytes of this ProgressiveTsMuxingInformationByteRanges.

        The position of the last byte of the segment

        :return: The end_bytes of this ProgressiveTsMuxingInformationByteRanges.
        :rtype: int
        """
        return self._end_bytes

    @end_bytes.setter
    def end_bytes(self, end_bytes):
        # type: (int) -> None
        """Sets the end_bytes of this ProgressiveTsMuxingInformationByteRanges.

        The position of the last byte of the segment

        :param end_bytes: The end_bytes of this ProgressiveTsMuxingInformationByteRanges.
        :type: int
        """

        if end_bytes is not None:
            if not isinstance(end_bytes, int):
                raise TypeError("Invalid type for `end_bytes`, type has to be `int`")

        self._end_bytes = end_bytes

    @property
    def duration(self):
        # type: () -> float
        """Gets the duration of this ProgressiveTsMuxingInformationByteRanges.

        The duration of the segment in seconds

        :return: The duration of this ProgressiveTsMuxingInformationByteRanges.
        :rtype: float
        """
        return self._duration

    @duration.setter
    def duration(self, duration):
        # type: (float) -> None
        """Sets the duration of this ProgressiveTsMuxingInformationByteRanges.

        The duration of the segment in seconds

        :param duration: The duration of this ProgressiveTsMuxingInformationByteRanges.
        :type: float
        """

        if duration is not None:
            if not isinstance(duration, (float, int)):
                raise TypeError("Invalid type for `duration`, type has to be `float`")

        self._duration = duration

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProgressiveTsMuxingInformationByteRanges):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.manifests.smooth.contentprotection.contentprotection_api import ContentprotectionApi
from bitmovin_api_sdk.encoding.manifests.smooth.contentprotection.smooth_manifest_content_protection_list_query_params import SmoothManifestContentProtectionListQueryParams



from bitmovin_api_sdk.encoding.configurations.audio.passthrough.passthrough_api import PassthroughApi
from bitmovin_api_sdk.encoding.configurations.audio.passthrough.passthrough_audio_configuration_list_query_params import PassthroughAudioConfigurationListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class AutoRepresentation(object):
    @poscheck_model
    def __init__(self,
                 adopt_configuration_threshold=None):
        # type: (float) -> None

        self._adopt_configuration_threshold = None
        self.discriminator = None

        if adopt_configuration_threshold is not None:
            self.adopt_configuration_threshold = adopt_configuration_threshold

    @property
    def openapi_types(self):
        types = {
            'adopt_configuration_threshold': 'float'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'adopt_configuration_threshold': 'adoptConfigurationThreshold'
        }
        return attributes

    @property
    def adopt_configuration_threshold(self):
        # type: () -> float
        """Gets the adopt_configuration_threshold of this AutoRepresentation.

        This is the threshold that determines whether the settings of the lower or the upper template representation (codec configuration) should be used, when representations are added automatically. The value must be between 0 and 1. Values nearer 0 will favour the higher representation, values nearer 1 will favour the lower representation.

        :return: The adopt_configuration_threshold of this AutoRepresentation.
        :rtype: float
        """
        return self._adopt_configuration_threshold

    @adopt_configuration_threshold.setter
    def adopt_configuration_threshold(self, adopt_configuration_threshold):
        # type: (float) -> None
        """Sets the adopt_configuration_threshold of this AutoRepresentation.

        This is the threshold that determines whether the settings of the lower or the upper template representation (codec configuration) should be used, when representations are added automatically. The value must be between 0 and 1. Values nearer 0 will favour the higher representation, values nearer 1 will favour the lower representation.

        :param adopt_configuration_threshold: The adopt_configuration_threshold of this AutoRepresentation.
        :type: float
        """

        if adopt_configuration_threshold is not None:
            if not isinstance(adopt_configuration_threshold, (float, int)):
                raise TypeError("Invalid type for `adopt_configuration_threshold`, type has to be `float`")

        self._adopt_configuration_threshold = adopt_configuration_threshold

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AutoRepresentation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class ColorTransfer(Enum):
    UNSPECIFIED = "UNSPECIFIED"
    BT709 = "BT709"
    GAMMA22 = "GAMMA22"
    GAMMA28 = "GAMMA28"
    SMPTE170M = "SMPTE170M"
    SMPTE240M = "SMPTE240M"
    LINEAR = "LINEAR"
    LOG = "LOG"
    LOG_SQRT = "LOG_SQRT"
    IEC61966_2_4 = "IEC61966_2_4"
    BT1361_ECG = "BT1361_ECG"
    IEC61966_2_1 = "IEC61966_2_1"
    BT2020_10 = "BT2020_10"
    BT2020_12 = "BT2020_12"
    SMPTE2084 = "SMPTE2084"
    SMPTE428 = "SMPTE428"
    ARIB_STD_B67 = "ARIB_STD_B67"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.atmosphere import Atmosphere
from bitmovin_api_sdk.models.location import Location
import pprint
import six


class Setting(object):
    @poscheck_model
    def __init__(self,
                 location=None,
                 time_of_day=None,
                 atmosphere=None):
        # type: (Location, string_types, Atmosphere) -> None

        self._location = None
        self._time_of_day = None
        self._atmosphere = None
        self.discriminator = None

        if location is not None:
            self.location = location
        if time_of_day is not None:
            self.time_of_day = time_of_day
        if atmosphere is not None:
            self.atmosphere = atmosphere

    @property
    def openapi_types(self):
        types = {
            'location': 'Location',
            'time_of_day': 'string_types',
            'atmosphere': 'Atmosphere'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'location': 'location',
            'time_of_day': 'timeOfDay',
            'atmosphere': 'atmosphere'
        }
        return attributes

    @property
    def location(self):
        # type: () -> Location
        """Gets the location of this Setting.


        :return: The location of this Setting.
        :rtype: Location
        """
        return self._location

    @location.setter
    def location(self, location):
        # type: (Location) -> None
        """Sets the location of this Setting.


        :param location: The location of this Setting.
        :type: Location
        """

        if location is not None:
            if not isinstance(location, Location):
                raise TypeError("Invalid type for `location`, type has to be `Location`")

        self._location = location

    @property
    def time_of_day(self):
        # type: () -> string_types
        """Gets the time_of_day of this Setting.


        :return: The time_of_day of this Setting.
        :rtype: string_types
        """
        return self._time_of_day

    @time_of_day.setter
    def time_of_day(self, time_of_day):
        # type: (string_types) -> None
        """Sets the time_of_day of this Setting.


        :param time_of_day: The time_of_day of this Setting.
        :type: string_types
        """

        if time_of_day is not None:
            if not isinstance(time_of_day, string_types):
                raise TypeError("Invalid type for `time_of_day`, type has to be `string_types`")

        self._time_of_day = time_of_day

    @property
    def atmosphere(self):
        # type: () -> Atmosphere
        """Gets the atmosphere of this Setting.


        :return: The atmosphere of this Setting.
        :rtype: Atmosphere
        """
        return self._atmosphere

    @atmosphere.setter
    def atmosphere(self, atmosphere):
        # type: (Atmosphere) -> None
        """Sets the atmosphere of this Setting.


        :param atmosphere: The atmosphere of this Setting.
        :type: Atmosphere
        """

        if atmosphere is not None:
            if not isinstance(atmosphere, Atmosphere):
                raise TypeError("Invalid type for `atmosphere`, type has to be `Atmosphere`")

        self._atmosphere = atmosphere

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Setting):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class ForceFlushMode(Enum):
    DISABLED = "DISABLED"
    ALL_FRAMES = "ALL_FRAMES"
    SLICE_TYPE = "SLICE_TYPE"



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.reset_live_manifest_time_shift import ResetLiveManifestTimeShift
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError


class ResetLiveManifestTimeshiftApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(ResetLiveManifestTimeshiftApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, encoding_id, reset_live_manifest_time_shift, **kwargs):
        # type: (string_types, ResetLiveManifestTimeShift, dict) -> ResetLiveManifestTimeShift
        """Reset Live manifest time-shift

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param reset_live_manifest_time_shift: Removes older segments from live manifests. This resets or reduces the time-shift (DVR) window. The &#x60;residualPeriod&#x60; value determines how many seconds will remain in the time-shift window. The original time-shift window does not change. Newer segments will be added and not removed from the  manifest until the original time-shift duration is reached again.  Currently, only HLS live manifests are supported. 
        :type reset_live_manifest_time_shift: ResetLiveManifestTimeShift, required
        :return: Reset Live manifest time-shift request
        :rtype: ResetLiveManifestTimeShift
        """

        return self.api_client.post(
            '/encoding/encodings/{encoding_id}/live/reset-live-manifest-timeshift',
            reset_live_manifest_time_shift,
            path_params={'encoding_id': encoding_id},
            type=ResetLiveManifestTimeShift,
            **kwargs
        )



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.live_standby_pool_encoding import LiveStandbyPoolEncoding
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError


class ActionsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(ActionsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def acquire_encoding(self, pool_id, **kwargs):
        # type: (string_types, dict) -> LiveStandbyPoolEncoding
        """Acquire an encoding from a standby pool

        :param pool_id: Id of the standby pool
        :type pool_id: string_types, required
        :return:
        :rtype: LiveStandbyPoolEncoding
        """

        return self.api_client.post(
            '/encoding/live/standby-pools/{pool_id}/actions/acquire-encoding',
            path_params={'pool_id': pool_id},
            type=LiveStandbyPoolEncoding,
            **kwargs
        )

    def delete_error_encodings(self, pool_id, **kwargs):
        # type: (string_types, dict) -> LiveStandbyPoolEncoding
        """Delete error encodings from the standby pool

        :param pool_id: Id of the standby pool
        :type pool_id: string_types, required
        :return:
        :rtype: LiveStandbyPoolEncoding
        """

        return self.api_client.post(
            '/encoding/live/standby-pools/{pool_id}/actions/delete-error-encodings',
            path_params={'pool_id': pool_id},
            type=LiveStandbyPoolEncoding,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.ai_scene_analysis_asset_description import AiSceneAnalysisAssetDescription
from bitmovin_api_sdk.models.ai_scene_analysis_automatic_ad_placement import AiSceneAnalysisAutomaticAdPlacement
import pprint
import six


class AiSceneAnalysisFeatures(object):
    @poscheck_model
    def __init__(self,
                 asset_description=None,
                 automatic_ad_placement=None):
        # type: (AiSceneAnalysisAssetDescription, AiSceneAnalysisAutomaticAdPlacement) -> None

        self._asset_description = None
        self._automatic_ad_placement = None
        self.discriminator = None

        if asset_description is not None:
            self.asset_description = asset_description
        if automatic_ad_placement is not None:
            self.automatic_ad_placement = automatic_ad_placement

    @property
    def openapi_types(self):
        types = {
            'asset_description': 'AiSceneAnalysisAssetDescription',
            'automatic_ad_placement': 'AiSceneAnalysisAutomaticAdPlacement'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'asset_description': 'assetDescription',
            'automatic_ad_placement': 'automaticAdPlacement'
        }
        return attributes

    @property
    def asset_description(self):
        # type: () -> AiSceneAnalysisAssetDescription
        """Gets the asset_description of this AiSceneAnalysisFeatures.

        AI scene analysis will create an asset description file. 

        :return: The asset_description of this AiSceneAnalysisFeatures.
        :rtype: AiSceneAnalysisAssetDescription
        """
        return self._asset_description

    @asset_description.setter
    def asset_description(self, asset_description):
        # type: (AiSceneAnalysisAssetDescription) -> None
        """Sets the asset_description of this AiSceneAnalysisFeatures.

        AI scene analysis will create an asset description file. 

        :param asset_description: The asset_description of this AiSceneAnalysisFeatures.
        :type: AiSceneAnalysisAssetDescription
        """

        if asset_description is not None:
            if not isinstance(asset_description, AiSceneAnalysisAssetDescription):
                raise TypeError("Invalid type for `asset_description`, type has to be `AiSceneAnalysisAssetDescription`")

        self._asset_description = asset_description

    @property
    def automatic_ad_placement(self):
        # type: () -> AiSceneAnalysisAutomaticAdPlacement
        """Gets the automatic_ad_placement of this AiSceneAnalysisFeatures.

        Ad markers placed on detected scene changes and configured positions. 

        :return: The automatic_ad_placement of this AiSceneAnalysisFeatures.
        :rtype: AiSceneAnalysisAutomaticAdPlacement
        """
        return self._automatic_ad_placement

    @automatic_ad_placement.setter
    def automatic_ad_placement(self, automatic_ad_placement):
        # type: (AiSceneAnalysisAutomaticAdPlacement) -> None
        """Sets the automatic_ad_placement of this AiSceneAnalysisFeatures.

        Ad markers placed on detected scene changes and configured positions. 

        :param automatic_ad_placement: The automatic_ad_placement of this AiSceneAnalysisFeatures.
        :type: AiSceneAnalysisAutomaticAdPlacement
        """

        if automatic_ad_placement is not None:
            if not isinstance(automatic_ad_placement, AiSceneAnalysisAutomaticAdPlacement):
                raise TypeError("Invalid type for `automatic_ad_placement`, type has to be `AiSceneAnalysisAutomaticAdPlacement`")

        self._automatic_ad_placement = automatic_ad_placement

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AiSceneAnalysisFeatures):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class InvitationStatus(Enum):
    PENDING = "PENDING"
    ACCEPTED = "ACCEPTED"
